/*
*******************************************************************************
**
**  This device driver was created by Applilet2 for 78K0/Kx2
**  8-Bit Single-Chip Microcontrollers
**
**  Copyright(C) NEC Electronics Corporation 2002 - 2009
**  All rights reserved by NEC Electronics Corporation.
**
**  This program should be used on your own responsibility.
**  NEC Electronics Corporation assumes no responsibility for any losses
**  incurred by customers or third parties arising from the use of this file.
**
**  Filename :	Serial_user.c
**  Abstract :	This file implements device driver for Serial module.
**  APIlib :	Applilet2 for 78K0/Kx2 V2.41 [29 Apr. 2008]
**
**  Device :	uPD78F0515_48
**
**  Compiler :	CC78K0
**
**  Creation date:	2009/04/02
**  
*******************************************************************************
*/

#pragma interrupt INTIIC0 MD_INTIIC0
/*
*******************************************************************************
**  Include files
*******************************************************************************
*/
#include "macrodriver.h"
#include "Serial.h"
/* Start user code for include definition. Do not edit comment generated here */
/* End user code for include definition. Do not edit comment generated here */
#include "user_define.h"

/*
*******************************************************************************
**  Global define
*******************************************************************************
*/
extern	volatile UCHAR	gIic0MasterStatusFlag; 
extern	volatile UCHAR	gIic0SlaveStatusFlag;
extern	volatile USHORT	gIic0TxCnt;
extern	volatile UCHAR*	gpIic0TxAddress;
extern	volatile UCHAR*	gpIic0RxAddress;
extern	volatile USHORT	gIic0RxCnt;
extern	volatile USHORT	gIic0RxLen;
/* Start user code for global definition. Do not edit comment generated here */
/* End user code for global definition. Do not edit comment generated here */

extern	unsigned char	eeprom_finish;

/*
**-----------------------------------------------------------------------------
**
**	Abstract:
**		This function is INTIIC0 interrupt service routine.
**
**	Parameters:
**		None
**
**	Returns:
**		None
**
**-----------------------------------------------------------------------------
*/
__interrupt void MD_INTIIC0( void )
{
	if (IICS0 & IIC0_STATUS_MASTER)
	{
		IIC0_MasterHandler();
	}
}

/*
**-----------------------------------------------------------------------------
**
**	Abstract:
**		This function is IIC0 master handler.
**
**	Parameters:
**		None
**
**	Returns:
**		None
**
**-----------------------------------------------------------------------------
*/
void IIC0_MasterHandler( void )
{
	/* Control for communication */
	if (IICBSY == 0 && gIic0TxCnt != 0)
	{
	}
	/* Control for sended address */
	else
	{
		if (!(gIic0MasterStatusFlag & ADDRESS_COMPLETE))
		{
			if (ACKD0 == 1)
			{
				gIic0MasterStatusFlag |= ADDRESS_COMPLETE;	/* address complete */
				if (TRC0 == 1)
				{
					WTIM0 = 1;
					if (gIic0TxCnt > 0)
					{
						IIC0 = *gpIic0TxAddress;
						gpIic0TxAddress++;
						gIic0TxCnt--;
					}
					else
					{
						CALL_IIC0_MasterSendEnd();
					}
				}
				else
				{
					ACKE0 = 1;
					WTIM0 = 0;
					WREL0 = 1;
				}
			}
			else
			{
			}
		}
		/* Master send control */
		else if (TRC0 == 1)
		{
			if (ACKD0 == 0 && gIic0TxCnt != 0)
			{
			}
			else if (gIic0TxCnt > 0)
			{
				IIC0 = *gpIic0TxAddress;
				gpIic0TxAddress++;
				gIic0TxCnt--;
			}
			else
			{
				CALL_IIC0_MasterSendEnd();
			}
		}
		/* Master receive control */
		else
		{
			if (gIic0RxCnt < gIic0RxLen)
			{
				*gpIic0RxAddress = IIC0;
				gpIic0RxAddress++;
				gIic0RxCnt++;
				if (gIic0RxCnt == gIic0RxLen)
				{
					ACKE0 = 0;
					WREL0 = 1;
					WTIM0=1;
					CALL_IIC0_MasterReceiveEnd();
				}
				else
					WREL0 = 1;
			}
			else
				WREL0 = 1;
		}
	}
}

/*
**-----------------------------------------------------------------------------
**
**	Abstract:
**		This function callback function open for users operation when IIC0 master receive finish.
**
**	Parameters:
**		None
**
**	Returns:
**		None
**
**-----------------------------------------------------------------------------
*/
void CALL_IIC0_MasterReceiveEnd( void )
{
	SPT0 = 1;
	eeprom_finish=1;	
	/* Start user code. Do not edit comment generated here */
	/* End user code. Do not edit comment generated here */
}

/*
**-----------------------------------------------------------------------------
**
**	Abstract:
**		This function callback function open for users operation when IIC0 master transmit finish.
**
**	Parameters:
**		None
**
**	Returns:
**		None
**
**-----------------------------------------------------------------------------
*/
void CALL_IIC0_MasterSendEnd( void )
{
	SPT0 = 1;
	eeprom_finish=1;	
	/* Start user code. Do not edit comment generated here */
	/* End user code. Do not edit comment generated here */
}

/* Start adding user code. Do not edit comment generated here */
/* End user code adding. Do not edit comment generated here */


